@@ -1,8 +1,7 @@
-use std::path::Path;
-
 use cfg_if::cfg_if;
 
 use crate::io;
+use crate::path::Path;
 use crate::task::blocking;
 
 /// Reads metadata for a path.
@@ -37,7 +36,7 @@ use crate::task::blocking;
 /// ```
 pub async fn metadata<P: AsRef<Path>>(path: P) -> io::Result<Metadata> {
     let path = path.as_ref().to_owned();
-    blocking::spawn(async move { std::fs::metadata(path) }).await
+    blocking::spawn(move || std::fs::metadata(path)).await
 }
 
 cfg_if! {
