@@ -1,10 +1,10 @@
-use std::path::Path;
+use std::future::Future;
 
 use cfg_if::cfg_if;
 
 use crate::fs::File;
-use crate::future::Future;
 use crate::io;
+use crate::path::Path;
 use crate::task::blocking;
 
 /// A builder for opening files with configurable options.
@@ -286,7 +286,7 @@ impl OpenOptions {
     pub fn open<P: AsRef<Path>>(&self, path: P) -> impl Future<Output = io::Result<File>> {
         let path = path.as_ref().to_owned();
         let options = self.0.clone();
-        async move { blocking::spawn(async move { options.open(path).map(|f| f.into()) }).await }
+        async move { blocking::spawn(move || options.open(path).map(|f| f.into())).await }
     }
 }
 
