@@ -1,10 +1,8 @@
 use std::pin::Pin;
 
-use futures_io::AsyncBufRead;
-
 use super::read_until_internal;
 use crate::future::Future;
-use crate::io;
+use crate::io::{self, BufRead};
 use crate::task::{Context, Poll};
 
 #[doc(hidden)]
@@ -16,7 +14,7 @@ pub struct ReadUntilFuture<'a, T: Unpin + ?Sized> {
     pub(crate) read: usize,
 }
 
-impl<T: AsyncBufRead + Unpin + ?Sized> Future for ReadUntilFuture<'_, T> {
+impl<T: BufRead + Unpin + ?Sized> Future for ReadUntilFuture<'_, T> {
     type Output = io::Result<usize>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
