@@ -1,10 +1,8 @@
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io;
 use std::pin::Pin;
 
-use futures_io::AsyncRead;
+use crate::future::Future;
+use crate::io::{self, Read};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -13,7 +11,7 @@ pub struct ReadFuture<'a, T: Unpin + ?Sized> {
     pub(crate) buf: &'a mut [u8],
 }
 
-impl<T: AsyncRead + Unpin + ?Sized> Future for ReadFuture<'_, T> {
+impl<T: Read + Unpin + ?Sized> Future for ReadFuture<'_, T> {
     type Output = io::Result<usize>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
