@@ -1,11 +1,9 @@
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io;
 use std::mem;
 use std::pin::Pin;
 
-use futures_io::AsyncRead;
+use crate::future::Future;
+use crate::io::{self, Read};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -14,7 +12,7 @@ pub struct ReadExactFuture<'a, T: Unpin + ?Sized> {
     pub(crate) buf: &'a mut [u8],
 }
 
-impl<T: AsyncRead + Unpin + ?Sized> Future for ReadExactFuture<'_, T> {
+impl<T: Read + Unpin + ?Sized> Future for ReadExactFuture<'_, T> {
     type Output = io::Result<()>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
