@@ -1,11 +1,9 @@
-use crate::future::Future;
-use crate::task::{Context, Poll};
-
-use std::io;
 use std::mem;
 use std::pin::Pin;
 
-use futures_io::AsyncWrite;
+use crate::future::Future;
+use crate::io::{self, Write};
+use crate::task::{Context, Poll};
 
 #[doc(hidden)]
 #[allow(missing_debug_implementations)]
@@ -14,7 +12,7 @@ pub struct WriteAllFuture<'a, T: Unpin + ?Sized> {
     pub(crate) buf: &'a [u8],
 }
 
-impl<T: AsyncWrite + Unpin + ?Sized> Future for WriteAllFuture<'_, T> {
+impl<T: Write + Unpin + ?Sized> Future for WriteAllFuture<'_, T> {
     type Output = io::Result<()>;
 
     fn poll(mut self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output> {
